@@ -6,22 +6,24 @@ Swagger2 - Swagger RESTful API Documentation
 
 =head1 VERSION
 
-0.35
+0.36
 
 =head1 DESCRIPTION
 
-THIS MODULE IS EXPERIMENTAL! ANY CHANGES CAN HAPPEN!
-
 L<Swagger2> is a module for generating, parsing and transforming
 L<swagger|http://swagger.io/> API documentation. It has support for reading
 swagger specification in JSON notation and it can also read YAML files,
 if a L</YAML parser> is installed.
 
+=head2 Mojolicious server side code generator
+
 This distribution comes with a L<Mojolicious> plugin,
 L<Mojolicious::Plugin::Swagger2>, which can set up routes and perform input
 and output validation.
 
-It also comes with a L<Swagger2::Client> generator, which converts the client
+=head2 Mojolicious client side code generator
+
+Swagger2 also comes with a L<Swagger2::Client> generator, which converts the client
 spec to perl code in memory.
 
 =head1 RECOMMENDED MODULES
@@ -59,7 +61,7 @@ use File::Spec;
 use constant CACHE_DIR => $ENV{SWAGGER2_CACHE_DIR} || '';
 use constant DEBUG     => $ENV{SWAGGER2_DEBUG}     || 0;
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 # Should be considered internal
 our @SPEC_FILE = (File::Spec->splitdir(File::Basename::dirname(__FILE__)), 'Swagger2', 'schema.json');
